@@ -170,7 +170,7 @@ stat_quant_band <- function(mapping = NULL,
       if (method == "rq") {
         formula <- y ~ x
       } else if (method == "rqss") {
-        formula <- y ~ quantreg::qss(x, lambda = 1, constraint = "N")
+        formula <- y ~ qss(x)
       }
     }
     if (is.na(orientation)) {
@@ -297,6 +297,13 @@ quant_band_compute_group_fun <- function(data,
                  formula = formula, weight = data[["weight"]], grid = grid,
                  method.args = method.args, orientation = "x",
                  make.groups = FALSE)
+
+  missing <- sapply(X =  z.ls,
+                    FUN = function(x) {!nrow(x)})
+  if (any(missing)) {
+    return(data.frame())
+  }
+
   z <- z.ls[[2]]
   z[["ymin"]] <- z.ls[[1]][["y"]]
   z[["quantile.ymin"]] <- z.ls[[1]][["quantile"]]
