@@ -55,13 +55,12 @@
 #'   the fitted coefficients and rho in labels.
 #' @param coef.keep.zeros logical Keep or drop trailing zeros when formatting
 #'   the fitted coefficients and F-value.
+#' @param decreasing logical It specifies the order of the terms in the
+#'   returned character string; in increasing (default) or decreasing powers.
 #' @param label.x,label.y \code{numeric} with range 0..1 "normalized parent
 #'   coordinates" (npc units) or character if using \code{geom_text_npc()} or
 #'   \code{geom_label_npc()}. If using \code{geom_text()} or \code{geom_label()}
 #'   numeric in native data units. If too short they will be recycled.
-#' @param label.x.npc,label.y.npc \code{numeric} with range 0..1 (npc units)
-#'   DEPRECATED, use label.x and label.y instead; together with a geom
-#'   using npcx and npcy aesthetics.
 #' @param hstep,vstep numeric in npc units, the horizontal and vertical step
 #'   used between labels for different groups.
 #' @param output.type character One of \code{"expression"}, \code{"LaTeX"},
@@ -130,9 +129,30 @@
 #'   observations are of little interest and using larger values of \code{n.min}
 #'   than the default is usually wise.
 #'
+#' @section User-defined methods: User-defined functions can be passed as
+#'   argument to \code{method}. The requirements are 1) that the signature is
+#'   similar to that of functions from package 'quantreg' and 2) that the value
+#'   returned by the function is an object belonging to class \code{"rq"}, class
+#'   \code{"rqs"}, or an atomic \code{NA} value.
+#'
+#'   The \code{formula} and \code{tau} used to build the equation and quantile
+#'   labels aer extracted from the returned \code{"rq"} or \code{"rqs"} object
+#'   and can safely differ from the argument passed to parameter \code{formula}
+#'   in the call to \code{stat_poly_eq()}. Thus, user-defined methods can
+#'   implement both model selection or conditional skipping of labelling.
+#'
 #' @references Written as an answer to question 65695409 by Mark Neal at
 #'   Stackoverflow.
 #'
+#' @section Warning!: For the formatted equations to be valid, the fitted model
+#'   must be a polynomial, with or without intercept. If defined using
+#'   \code{poly()} the argument \code{raw = TRUE} must be passed. If defined
+#'   manually as powers of \code{x}, \strong{the terms must be in order of
+#'   increasing powers, with no missing intermediate power term.} Please, see
+#'   examples below. A check on the model is used to validate that it is a
+#'   polynomial, in most cases a warning is issued. Failing to comply with this
+#'   requirement results in the return of \code{NA} as the formatted equation.
+#'
 #' @section Aesthetics: \code{stat_quant_eq()} understands \code{x} and \code{y},
 #'   to be referenced in the \code{formula} and \code{weight} passed as argument
 #'   to parameter \code{weights} of \code{rq()}. All three must be mapped to
@@ -226,7 +246,17 @@
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   stat_quant_line() +
-#'   stat_quant_eq(use_label(c("eq", "method")))
+#'   stat_quant_eq(mapping = use_label("eq"))
+#'
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   stat_quant_line() +
+#'   stat_quant_eq(mapping = use_label("eq"), decreasing = TRUE)
+#'
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   stat_quant_line() +
+#'   stat_quant_eq(mapping = use_label("eq", "method"))
 #'
 #' # same formula as default
 #' ggplot(my.data, aes(x, y)) +
@@ -243,15 +273,15 @@
 #' # using color
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
-#'   stat_quant_line(aes(color = after_stat(quantile.f))) +
-#'   stat_quant_eq(aes(color = after_stat(quantile.f))) +
+#'   stat_quant_line(mapping = aes(color = after_stat(quantile.f))) +
+#'   stat_quant_eq(mapping = aes(color = after_stat(quantile.f))) +
 #'   labs(color = "Quantiles")
 #'
 #' # location and colour
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
-#'   stat_quant_line(aes(color = after_stat(quantile.f))) +
-#'   stat_quant_eq(aes(color = after_stat(quantile.f)),
+#'   stat_quant_line(mapping = aes(color = after_stat(quantile.f))) +
+#'   stat_quant_eq(mapping = aes(color = after_stat(quantile.f)),
 #'                 label.y = "bottom", label.x = "right") +
 #'   labs(color = "Quantiles")
 #'
@@ -301,7 +331,7 @@
 #'        grp.label = group)) +
 #'   geom_point() +
 #'   stat_quant_band(formula = formula, color = "black", linewidth = 0.75) +
-#'   stat_quant_eq(use_label(c("grp", "eq"), sep = "*\": \"*"),
+#'   stat_quant_eq(mapping = use_label("grp", "eq", sep = "*\": \"*"),
 #'                 formula = formula) +
 #'   expand_limits(y = 3) +
 #'   theme_classic()
@@ -312,7 +342,7 @@
 #' ggplot(my.data, aes(x, y + 1)) +
 #'   geom_point() +
 #'   stat_quant_line(formula = formula.trans) +
-#'   stat_quant_eq(use_label("eq"),
+#'   stat_quant_eq(mapping = use_label("eq"),
 #'                formula = formula.trans,
 #'                eq.x.rhs = "~x^2",
 #'                eq.with.lhs = "y + 1~~`=`~~")
@@ -333,10 +363,10 @@
 #' ggplot(my.data, aes(x, y2, color = group, grp.label = group)) +
 #'   geom_point() +
 #'   stat_quant_line(method = "rq", formula = formula,
-#'                 quantiles = c(0.05, 0.5, 0.95),
-#'                 linewidth = 0.5) +
-#'   stat_quant_eq(aes(label = paste(after_stat(grp.label), "*\": \"*",
-#'                                    after_stat(eq.label), sep = "")),
+#'                   quantiles = c(0.05, 0.5, 0.95),
+#'                   linewidth = 0.5) +
+#'   stat_quant_eq(mapping = aes(label = paste(after_stat(grp.label), "*\": \"*",
+#'                                             after_stat(eq.label), sep = "")),
 #'                 quantiles = c(0.05, 0.5, 0.95),
 #'                 formula = formula, size = 3)
 #'
@@ -345,9 +375,9 @@
 #'   geom_point() +
 #'   stat_quant_band(method = "rq", formula = formula,
 #'                   quantiles = c(0.05, 0.5, 0.95)) +
-#'   stat_quant_eq(aes(label = sprintf("%s*\": \"*%s",
-#'                                     after_stat(grp.label),
-#'                                     after_stat(eq.label))),
+#'   stat_quant_eq(mapping = aes(label = sprintf("%s*\": \"*%s",
+#'                                               after_stat(grp.label),
+#'                                               after_stat(eq.label))),
 #'                 quantiles = c(0.05, 0.5, 0.95),
 #'                 formula = formula, size = 3)
 #'
@@ -377,7 +407,7 @@
 #' if (gginnards.installed)
 #'   ggplot(my.data, aes(x, y)) +
 #'     geom_point() +
-#'     stat_quant_eq(aes(label = after_stat(eq.label)),
+#'     stat_quant_eq(mapping = aes(label = after_stat(eq.label)),
 #'                   formula = formula, geom = "debug",
 #'                   output.type = "markdown")
 #'
@@ -419,12 +449,12 @@ stat_quant_eq <- function(mapping = NULL, data = NULL,
                          eq.x.rhs = NULL,
                          coef.digits = 3,
                          coef.keep.zeros = TRUE,
-                         rho.digits = 2,
+                         decreasing = getOption("ggpmisc.decreasing.poly.eq", FALSE),
+                         rho.digits = 4,
                          label.x = "left", label.y = "top",
-                         label.x.npc = NULL, label.y.npc = NULL,
                          hstep = 0,
                          vstep = NULL,
-                         output.type = "expression",
+                         output.type = NULL,
                          na.rm = FALSE,
                          orientation = NA,
                          parse = NULL,
@@ -438,6 +468,7 @@ stat_quant_eq <- function(mapping = NULL, data = NULL,
       formula <- x ~ y
     }
   }
+
   # we guess orientation from formula
   if (is.na(orientation)) {
     if (grepl("x", as.character(formula)[2])) {
@@ -449,18 +480,20 @@ stat_quant_eq <- function(mapping = NULL, data = NULL,
     }
   }
 
-  # backwards compatibility
-  if (!is.null(label.x.npc)) {
-    stopifnot(grepl("_npc", geom))
-    label.x <- label.x.npc
-  }
-  if (!is.null(label.y.npc)) {
-    stopifnot(grepl("_npc", geom))
-    label.y <- label.y.npc
+  if (is.null(output.type)) {
+    if (geom %in% c("richtext", "textbox", "marquee")) {
+      output.type <- "markdown"
+    } else {
+      output.type <- "expression"
+    }
   }
   if (is.null(parse)) {
     parse <- output.type == "expression"
   }
+
+  # is the model formula that of complete and increasing polynomial?
+  mk.eq.label <- output.type != "numeric" && check_poly_formula(formula, orientation)
+
   if (is.character(method)) {
     if (grepl("^lm|^rlm", method)) {
       stop("Methods 'lm' and 'rlm' not supported, please use 'stat_poly_eq()'.")
@@ -485,8 +518,10 @@ stat_quant_eq <- function(mapping = NULL, data = NULL,
                    n.min = n.min,
                    eq.with.lhs = eq.with.lhs,
                    eq.x.rhs = eq.x.rhs,
+                   mk.eq.label = mk.eq.label,
                    coef.digits = coef.digits,
                    coef.keep.zeros = coef.keep.zeros,
+                   decreasing = decreasing,
                    rho.digits = rho.digits,
                    label.x = label.x,
                    label.y = label.y,
@@ -514,25 +549,27 @@ stat_quant_eq <- function(mapping = NULL, data = NULL,
 #'
 quant_eq_compute_group_fun <- function(data,
                                        scales,
-                                       formula,
-                                       quantiles,
-                                       method,
-                                       method.args,
-                                       n.min,
-                                       weight,
-                                       eq.with.lhs,
-                                       eq.x.rhs,
-                                       coef.digits,
-                                       coef.keep.zeros,
-                                       rho.digits,
-                                       label.x,
-                                       label.y,
-                                       hstep,
-                                       vstep,
-                                       npc.used,
-                                       output.type,
-                                       na.rm,
-                                       orientation) {
+                                       formula = y ~ x,
+                                       quantiles = c(0.25, 0.5, 0.75),
+                                       method = "rq:br",
+                                       method.args = list(),
+                                       n.min = 3L,
+                                       weight = 1,
+                                       eq.with.lhs = TRUE,
+                                       eq.x.rhs = NULL,
+                                       mk.eq.label = TRUE,
+                                       coef.digits = 3,
+                                       coef.keep.zeros = TRUE,
+                                       decreasing = FALSE,
+                                       rho.digits = 4,
+                                       label.x = "left",
+                                       label.y = "top",
+                                       hstep = 0,
+                                       vstep = 0.10,
+                                       npc.used = TRUE,
+                                       output.type = "expression",
+                                       na.rm = FALSE,
+                                       orientation = "x") {
   force(data)
   force(method)
 
@@ -544,7 +581,6 @@ quant_eq_compute_group_fun <- function(data,
     warning("Decimal mark must be one of '.' or ',', not: '", decimal.mark, "'")
     decimal.mark <- "."
   }
-#  range.sep <- c("." = ", ", "," = "; ")[decimal.mark]
 
   num.quantiles <- length(quantiles)
 
@@ -663,6 +699,28 @@ quant_eq_compute_group_fun <- function(data,
   # so we silence selectively only these warnings
   withCallingHandlers({
     fm <- do.call(method, args = fun.args)
+  }, warning = function(w) {
+    if (startsWith(conditionMessage(w), "partial match of") ||
+        startsWith(conditionMessage(w), "partial argument match of")) {
+      invokeRestart("muffleWarning")
+    }
+  })
+
+  # allow model formula and tau selection by method functions
+  if (!length(fm) || (is.atomic(fm) && is.na(fm))) {
+    return(data.frame())
+  } else if (inherits(fm, "rq") || inherits(fm, "rqs")) {
+    # allow model formula selection by the model fit method
+    # extract formula from fitted model if possible, but fall back on argument if needed
+    formula.ls <- fail_safe_formula(fm, fun.args, verbose = TRUE)
+    quantiles <- fm[["tau"]]
+  } else {
+    stop("Fitted model object does not inherit from class \"rq\" or \"rqs\" as expected")
+  }
+
+  # quantreg contains code with partial matching of names!
+  # so we silence selectively only these warnings
+  withCallingHandlers({
     fm.summary <- summary(fm)
   }, warning = function(w) {
     if (startsWith(conditionMessage(w), "partial match of") ||
@@ -673,16 +731,6 @@ quant_eq_compute_group_fun <- function(data,
 
   fm.class <- class(fm)
 
-  # allow model formula and tau selection by method functions
-  if (inherits(fm, "rq") || inherits(fm, "rqs")) {
-    # allow model formula selection by the model fit method
-    # extract formula from fitted model if possible, but fall back on argument if needed
-    formula.ls <- fail_safe_formula(fm, fun.args, verbose = TRUE)
-    quantiles <- fm[["tau"]]
-  } else {
-    stop("Fitted model object does not inherit from class \"rq\" or \"rqs\" as expected")
-  }
-
   # class of returned summary value depends on length of quantiles vector
   if (!inherits(fm.summary, "summary.rqs")) {
     fm.summary <- list(fm.summary)
@@ -725,94 +773,87 @@ quant_eq_compute_group_fun <- function(data,
                         b_0.constant = forced.origin)
     z <- cbind(z, tibble::as_tibble(t(coefs.mt)))
   } else {
-    # set defaults needed to assemble the equation as a character string
-    if (is.null(eq.x.rhs)) {
-      eq.x.rhs <- build_eq.x.rhs(output.type = output.type,
-                                 orientation = orientation)
-    }
+    if (mk.eq.label) {
+      # set defaults needed to assemble the equation as a character string
+      if (is.null(eq.x.rhs)) {
+        eq.x.rhs <- build_eq.x.rhs(output.type = output.type,
+                                   orientation = orientation)
+      }
 
-    if (is.character(eq.with.lhs)) {
-      lhs <- eq.with.lhs
-      eq.with.lhs <- TRUE
-    } else if (eq.with.lhs) {
-      lhs <- build_lhs(output.type = output.type,
-                       orientation = orientation)
-    } else {
-      lhs <- character(0)
+      if (is.character(eq.with.lhs)) {
+        lhs <- eq.with.lhs
+        eq.with.lhs <- TRUE
+      } else if (eq.with.lhs) {
+        lhs <- build_lhs(output.type = output.type,
+                         orientation = orientation)
+      } else {
+        lhs <- character(0)
+      }
     }
-
     # build labels
     stopifnot(coef.digits > 0)
     if (coef.digits < 3) {
       warning("'coef.digits < 3' Likely information loss!")
     }
 
-    eq.char <- AIC.char <- rho.char <- character(num.quantiles)
+    qtl.char <- n.char <- eq.char <- AIC.char <- rho.char <- character(num.quantiles)
     for (q in seq_along(quantiles)) {
-      # build equation as a character string from the coefficient estimates
-      eq.char[q] <- coefs2poly_eq(coefs = coefs.ls[[q]],
-                                  coef.digits = coef.digits,
-                                  coef.keep.zeros = coef.keep.zeros,
-                                  eq.x.rhs = eq.x.rhs,
-                                  lhs = lhs,
+      if (mk.eq.label) {
+        # build equation as a character string from the coefficient estimates
+        eq.char[q] <- coefs2poly_eq(coefs = coefs.ls[[q]],
+                                    coef.digits = coef.digits,
+                                    coef.keep.zeros = coef.keep.zeros,
+                                    decreasing = decreasing,
+                                    eq.x.rhs = eq.x.rhs,
+                                    lhs = lhs,
+                                    output.type = output.type,
+                                    decimal.mark = decimal.mark)
+      } else {
+        eq.char[q] <- NA_character_
+      }
+      # build other label that vary with quantiles
+      AIC.char[q] <- plain_label(value = AIC[q],
+                                 value.name = "AIC",
+                                 digits = 4,
+                                 fixed = FALSE,
+                                 output.type = output.type,
+                                 decimal.mark = decimal.mark)
+      rho.char[q] <- r_label(value = rho[q],
+                             method = "spearman",
+                             digits = rho.digits,
+                             fixed = FALSE,
+                             output.type = output.type,
+                             decimal.mark = decimal.mark)
+      n.char[q] <- italic_label(value = n,
+                                value.name = "n",
+                                digits = 0,
+                                fixed = TRUE,
+                                output.type = output.type,
+                                decimal.mark = decimal.mark)
+      qtl.char[q] <- italic_label(value = quantiles[q],
+                                  value.name = "q",
+                                  digits = 2,
+                                  fixed = TRUE,
                                   output.type = output.type,
                                   decimal.mark = decimal.mark)
-
-      if (output.type == "expression" && coef.keep.zeros) {
-        AIC.char[q] <- sprintf_dm("\"%.4g\"", AIC[q], decimal.mark = decimal.mark)
-        rho.char[q] <- sprintf_dm("\"%#.3g\"", rho[q], decimal.mark = decimal.mark)
-      } else {
-        AIC.char[q] <- sprintf_dm("%.4g", AIC[q], decimal.mark = decimal.mark)
-        rho.char[q] <- sprintf_dm("%#.3g", rho[q], decimal.mark = decimal.mark)
-      }
     }
 
     # build data frames to return
-    if (output.type == "expression") {
-      z <- tibble::tibble(eq.label = eq.char,
-                          AIC.label = paste("AIC", AIC.char, sep = "~`=`~"),
-                          rho.label = paste("rho", rho.char, sep = "~`=`~"),
-                          n.label = paste("italic(n)~`=`~", n, sep = ""),
-                          grp.label = if (any(grp.label != ""))
-                                         paste(grp.label,
-                                            sprintf_dm("italic(q)~`=`~\"%.2f\"", quantiles, decimal.mark = decimal.mark),
-                                            sep = "*\", \"*")
-                                      else
-                                        sprintf_dm("italic(q)~`=`~\"%.2f\"", quantiles, decimal.mark = decimal.mark),
-                          method.label = paste("\"method: ", method.name, "\"", sep = ""),
-                          rq.method = rq.method,
-                          quantile = quantiles,
-                          quantile.f = quantiles.f,
-                          n = n)
-    } else if (output.type %in% c("latex", "tex", "text", "tikz")) {
-      z <- tibble::tibble(eq.label = eq.char,
-                          AIC.label = paste("AIC", AIC.char, sep = " = "),
-                          rho.label = paste("rho", rho.char, sep = " = "),
-                          n.label = paste("n = ", n, sep = ""),
-                          grp.label = paste(grp.label,
-                                            sprintf_dm("q = %.2f", quantiles, decimal.mark = decimal.mark)),
-                          method.label = paste("method: ", method.name, sep = ""),
-                          rq.method = rq.method,
-                          quantile = quantiles,
-                          quantile.f = quantiles.f,
-                          n = n)
-    } else if (output.type == "markdown") {
-      z <- tibble::tibble(eq.label = eq.char,
-                          AIC.label = paste("AIC", AIC.char, sep = " = "),
-                          rho.label = paste("rho", rho.char, sep = " = "),
-                          n.label = paste("_n_ = ", n, sep = ""),
-                          grp.label = paste(grp.label,
-                                            sprintf_dm("q = %.2f", quantiles, decimal.mark = decimal.mark)),
-                          method.label = paste("method: ", method.name, sep = ""),
-                          rq.method = rq.method,
-                          quantile = quantiles,
-                          quantile.f = quantiles.f,
-                          n = n)
-    } else {
-      warning("Unknown 'output.type' argument: ", output.type)
-    }
+    z <- data.frame(eq.label = eq.char,
+                    AIC.label = AIC.char,
+                    rho.label = rho.char,
+                    n.label = n.char,
+                    grp.label = grp.label,
+                    qtl.label = qtl.char,
+                    method.label = paste("\"method: ", method.name, "\"", sep = ""),
+                    rho = rho,
+                    rq.method = rq.method,
+                    quantile = quantiles,
+                    quantile.f = quantiles.f,
+                    n = n)
   }
 
+  # add members common to numeric and other output types
   z[["fm.method"]] <- method.name
   z[["fm.class"]] <- fm.class[1]
   z[["fm.formula"]] <- formula.ls
