@@ -53,7 +53,7 @@ ggplot(my.data, aes(x, y, color = group)) +
 ## -----------------------------------------------------------------------------
 ggplot(my.data, aes(x, y, color = group)) +
   geom_point() +
-  stat_correlation(mapping = use_label(c("R", "t", "P", "n")))
+  stat_correlation(mapping = use_label("R", "t", "P", "n"))
 
 ## -----------------------------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
@@ -118,7 +118,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(mapping = use_label(c("eq", "adj.R2")),
+  stat_poly_eq(mapping = use_label("eq", "adj.R2"),
                formula = formula) +
   labs(x = expression(italic(x)), y = expression(italic(y)))
 
@@ -139,7 +139,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(mapping = use_label(c("eq", "adj.R2"), sep = "~~italic(\"with\")~~"),
+  stat_poly_eq(mapping = use_label("eq", "adj.R2", sep = "~~italic(\"with\")~~"),
                formula = formula)
 
 ## ----eval=eval_flag-----------------------------------------------------------
@@ -147,7 +147,8 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = paste("atop(", after_stat(AIC.label), ",", after_stat(BIC.label), ")", sep = "")), 
+  stat_poly_eq(aes(label = paste("atop(", after_stat(AIC.label), ",", 
+                                 after_stat(BIC.label), ")", sep = "")), 
                formula = formula)
 
 ## ----eval=eval_flag-----------------------------------------------------------
@@ -173,7 +174,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(mapping = use_label(c("eq", "R2")),
+  stat_poly_eq(mapping = use_label("eq", "R2"),
                eq.with.lhs = "italic(h)~`=`~",
                eq.x.rhs = "~italic(z)",
                formula = formula) +
@@ -321,9 +322,9 @@ ggplot(my.data, aes(x, y2, colour = group)) +
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = y ~ x, color = "blue") +
-  stat_poly_eq(mapping = use_label(c("R2", "eq")), color = "blue") +
+  stat_poly_eq(mapping = use_label("R2", "eq"), color = "blue") +
   stat_poly_line(formula = y ~ x, color = "red", orientation = "y") +
-  stat_poly_eq(mapping = use_label(c("R2", "eq")), color = "red", orientation = "y",
+  stat_poly_eq(mapping = use_label("R2", "eq"), color = "red", orientation = "y",
                label.y = 0.9)
 
 ## -----------------------------------------------------------------------------
@@ -336,9 +337,9 @@ ggplot(my.data, aes(x, y)) +
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_ma_line(color = "blue") +
-  stat_ma_eq(mapping = use_label(c("R2", "eq")), color = "blue") +
+  stat_ma_eq(mapping = use_label("R2", "eq"), color = "blue") +
   stat_ma_line(color = "red", orientation = "y") +
-  stat_ma_eq(mapping = use_label(c("R2", "eq")), color = "red", orientation = "y",
+  stat_ma_eq(mapping = use_label("R2", "eq"), color = "red", orientation = "y",
              label.y = 0.9)
 
 ## ----warning=FALSE------------------------------------------------------------
@@ -360,7 +361,7 @@ ggplot(my.data, aes(x, y)) +
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_quant_band(formula = formula, color = "black", fill = "grey60") +
-  stat_quant_eq(aes(label = paste(after_stat(grp.label), "*\": \"*",
+  stat_quant_eq(aes(label = paste(after_stat(qtl.label), "*\": \"*",
                                   after_stat(eq.label), sep = "")),
                 formula = formula) +
   theme_classic()
@@ -369,7 +370,7 @@ ggplot(my.data, aes(x, y)) +
 ggplot(my.data, aes(x, y, color = group)) +
   geom_point() +
   stat_quant_line(formula = formula) +
-  stat_quant_eq(aes(label = paste(after_stat(grp.label), "*\": \"*",
+  stat_quant_eq(aes(label = paste(after_stat(qtl.label), "*\": \"*",
                                   after_stat(eq.label), sep = "")),
                formula = formula)
 
@@ -378,7 +379,8 @@ ggplot(my.data, aes(x, y, group = group, linetype = group,
                     shape = group, grp.label = group)) +
   geom_point() +
   stat_quant_line(formula = formula, quantiles = c(0.05, 0.95), color = "black") +
-  stat_quant_eq(aes(label = paste(after_stat(grp.label), "*\": \"*",
+  stat_quant_eq(aes(label = paste(after_stat(grp.label), "*\", \"*",
+                                  after_stat(qtl.label), "*\": \"*",
                                   after_stat(eq.label), sep = "")),
                 formula = formula, quantiles = c(0.05, 0.95)) +
   theme_classic()
@@ -393,12 +395,38 @@ ggplot(my.data, aes(x, y)) +
   stat_quant_eq(mapping = use_label("eq"), formula = x ~ y, color = "red", 
                 quantiles = 0.95, label.y = 0.9)
 
+## -----------------------------------------------------------------------------
+# position of contrasts' bars (manual)
+ggplot(mpg, aes(factor(cyl), hwy)) +
+  geom_boxplot(width = 0.33)  +
+  stat_multcomp(p.adjust.method = "bonferroni", 
+                adj.method.tag = 3,
+                size = 2.75) +
+  expand_limits(y = 0)
+
+## -----------------------------------------------------------------------------
+# position of contrasts' bars (manual)
+ggplot(mpg, aes(factor(cyl), hwy)) +
+  geom_boxplot(width = 0.33)  +
+  stat_multcomp(p.adjust.method = "bonferroni", 
+                adj.method.tag = -3,
+                size = 2.75) +
+  expand_limits(y = 0)
+
+## -----------------------------------------------------------------------------
+# position of contrasts' bars (manual)
+ggplot(mpg, aes(factor(cyl), hwy)) +
+  geom_boxplot(width = 0.33)  +
+  stat_multcomp(adj.method.tag = "ajustada",
+                size = 2.75) +
+  expand_limits(y = 0)
+
 ## -----------------------------------------------------------------------------
 # position of contrasts' bars (manual)
 ggplot(mpg, aes(factor(cyl), hwy)) +
   geom_boxplot(width = 0.33)  +
   stat_multcomp(label.y = c(7, 4, 1),
-                contrast.type = "Dunnet",
+                contrasts = "Dunnet",
                 size = 2.75) +
   expand_limits(y = 0)
 
@@ -422,14 +450,15 @@ means <-
 ggplot(mpg, aes(factor(cyl), hwy)) +
   stat_summary(fun.data = mean_se) +
   stat_multcomp(label.type = "letters",
-                label.y = means,
-                position = position_nudge(x = 0.22))
+                label.y = c(18, means), # 18 is for critical P label
+                position = position_nudge(x = 0.1))
 
 ## -----------------------------------------------------------------------------
 # Using other geometries
 ggplot(mpg, aes(factor(cyl), hwy)) +
   geom_boxplot(width = 0.33) +
   stat_multcomp(label.type = "letters",
+                adj.method.tag = FALSE,
                 geom = "label")
 
 ## -----------------------------------------------------------------------------
@@ -440,7 +469,7 @@ ggplot(mpg, aes(factor(cyl), hwy)) +
                 geom = "text",
                 label.y = "bottom",
                 vstep = 0,
-                contrast.type = "Dunnet")
+                contrasts = "Dunnet")
 
 ## -----------------------------------------------------------------------------
 ggplot(mpg, aes(factor(cyl), hwy)) +
@@ -451,7 +480,7 @@ ggplot(mpg, aes(factor(cyl), hwy)) +
                 geom = "text",
                 label.y = "bottom",
                 vstep = 0,
-                contrast.type = "Dunnet")
+                contrasts = "Dunnet")
 
 ## -----------------------------------------------------------------------------
 # use colour to show significance
@@ -468,10 +497,10 @@ ggplot(mpg, aes(factor(cyl), hwy)) +
   geom_boxplot(width = 0.33) +
   stat_multcomp(aes(fill = after_stat(p.value) < 0.01),
                 size = 2.5,
-                arrow = grid::arrow(angle = 90,
+                arrow = grid::arrow(angle = 45,
                                     length = unit(1, "mm"),
                                     ends = "both")) +
-  scale_fill_manual(values = c("white", "green"))
+  scale_fill_manual(values = c("white", "lightblue"))
 
 ## -----------------------------------------------------------------------------
 formula <- y ~ poly(x, 3, raw = TRUE)
@@ -853,7 +882,7 @@ ggplot(volcano_example.df,
   geom_point() +
   scale_x_logFC(name = "Transcript abundance%unit") +
   scale_y_Pvalue() +
-  scale_colour_outcome() +
+  scale_colour_outcome(values = "outcome:de") +
   stat_quadrant_counts(data = function(x) {subset(x, outcome != 0)})
 
 ## -----------------------------------------------------------------------------
