@@ -33,6 +33,54 @@ library(ggpmisc)
 
 test_that("quant_formulas", {
   withCallingHandlers({
+    vdiffr::expect_doppelganger("stat_quant_band_formula_missing",
+                                ggplot(my.data, aes(x, y)) +
+                                  geom_point() +
+                                  stat_quant_band()
+    )
+
+    vdiffr::expect_doppelganger("stat_quant_band_formula_missing_orientationy",
+                                ggplot(my.data, aes(x, y)) +
+                                  geom_point() +
+                                  stat_quant_band(orientation = "y")
+    )
+
+    vdiffr::expect_doppelganger("stat_quant_band_formula_missing_orientationx",
+                                ggplot(my.data, aes(x, y)) +
+                                  geom_point() +
+                                  stat_quant_band(orientation = "x")
+    )
+
+    vdiffr::expect_doppelganger("stat_quant_band_formula_missing_rqss",
+                                ggplot(my.data, aes(x, y)) +
+                                  geom_point() +
+                                  stat_quant_band(method = "rqss")
+    )
+
+    expect_error(ggplot(my.data, aes(x, y)) +
+                   stat_quant_band(method = "lm"))
+
+    expect_error(ggplot(my.data, aes(x, y)) +
+                   stat_quant_band(method = "lmodel2"))
+
+    vdiffr::expect_doppelganger("stat_quant_line_fm_NA",
+                                ggplot(my.data, aes(x, y)) +
+                                  geom_point() +
+                                  stat_quant_band(method = function(...) {NA})
+    )
+
+    vdiffr::expect_doppelganger("stat_quant_line_fm_NULL",
+                                ggplot(my.data, aes(x, y)) +
+                                  geom_point() +
+                                  stat_quant_band(method = function(...) {NULL})
+    )
+
+    vdiffr::expect_doppelganger("stat_quant_line_fm_missing",
+                                ggplot(my.data, aes(x, y)) +
+                                  geom_point() +
+                                  stat_quant_band(method = function(...) {list()})
+    )
+
     vdiffr::expect_doppelganger("stat_quant_band_formula_1",
                                 ggplot(my.data, aes(x, y)) +
                                   geom_point() +
